// ignore_for_file: non_constant_identifier_names

import 'package:flutter/cupertino.dart';
import 'package:pam_flutter/models/consent_message_model.dart';
import 'package:pam_flutter/pam_flutter.dart';
import 'package:pam_flutter/repositories/base_repository.dart';
import 'package:pam_flutter/repositories/types.dart';
import 'package:pam_flutter/utils/time_helper.dart';

class ConsentMessageTypes {
  static String get tracking_type => "tracking_type";

  static String get contacting_type => "contacting_type";
}

class ConsentMessageSettingConsentDetails {
  ConsentMessageSettingConsentDetails._();

  static String get terms_and_conditions => "TermsAndConditions";

  static String get analytics_cookies => "AnalyticsCookies";

  static String get email => "Email";

  static String get facebook_messenger => "FacebookMessenger";

  static String get line => "Line";

  static String get marketing_cookies => "MarketingCookies";

  static String get mobile_notification => "MobileNotification";

  static String get necessary_cookies => "NecessaryCookies";

  static String get preferences_cookies => "PreferencesCookies";

  static String get privacy_overview => "PrivacyOverview";

  static String get sms => "SMS";

  static String get social_media_cookies => "SocialMediaCookies";
}

class PDPARepository extends BaseDataRepository<ConsentMessageModel> {
  final BuildContext buildCtx;
  final IRepositoryOptions options;

  PDPARepository({
    required this.buildCtx,
    required this.options,
  }) : super(buildCtx, options);

  @override
  List<ConsentMessageModel> transforms(tss) {
    return ConsentMessageModel.toList(tss);
  }

  @override
  ConsentMessageModel? transform(ts) {
    return ConsentMessageModel.fromJson(ts);
  }

  void allowConsentSetting(String settingName, bool isAllowed) {
    try {
      this.toLoadingStatus();

      print("Inner isAllowed = $isAllowed");

      switch (settingName) {
        case "TermsAndConditions":
          print("Inner before = ${this.data?.Setting.TermsAndConditions.IsAllowed}");
          this.data?.Setting.TermsAndConditions.IsAllowed = true;
          print("Inner after = ${this.data?.Setting.TermsAndConditions.IsAllowed}");
          break;
        case "AnalyticsCookies":
          this.data?.Setting.AnalyticsCookies.IsAllowed = isAllowed;
          break;
        case "Email":
          this.data?.Setting.Email.IsAllowed = isAllowed;
          break;
        case "FacebookMessenger":
          this.data?.Setting.FacebookMessenger.IsAllowed = isAllowed;
          break;
        case "Line":
          this.data?.Setting.Line.IsAllowed = isAllowed;
          break;
        case "MarketingCookies":
          this.data?.Setting.MarketingCookies.IsAllowed = isAllowed;
          break;
        case "MobileNotification":
          this.data?.Setting.MobileNotification.IsAllowed = isAllowed;
          break;
        case "NecessaryCookies":
          this.data?.Setting.NecessaryCookies.IsAllowed = isAllowed;
          break;
        case "PreferencesCookies":
          this.data?.Setting.PreferencesCookies.IsAllowed = isAllowed;
          break;
        case "PrivacyOverview":
          this.data?.Setting.PrivacyOverview.IsAllowed = isAllowed;
          break;
        case "SMS":
          this.data?.Setting.SMS.IsAllowed = isAllowed;
          break;
        case "SocialMediaCookies":
          this.data?.Setting.SocialMediaCookies.IsAllowed = isAllowed;
          break;
        default:
      }
      this.dataSC.add(this.data);

      this.toLoadedStatus();
    } catch (e) {
      this.toErrorStatus(e);
    }
  }

  void allowAllConsentSetting() {
    try {
      this.toLoadingStatus();

      this.data?.Setting.TermsAndConditions.IsAllowed = true;
      this.data?.Setting.AnalyticsCookies.IsAllowed = true;
      this.data?.Setting.Email.IsAllowed = true;
      this.data?.Setting.FacebookMessenger.IsAllowed = true;
      this.data?.Setting.Line.IsAllowed = true;
      this.data?.Setting.MarketingCookies.IsAllowed = true;
      this.data?.Setting.MobileNotification.IsAllowed = true;
      this.data?.Setting.NecessaryCookies.IsAllowed = true;
      this.data?.Setting.PreferencesCookies.IsAllowed = true;
      this.data?.Setting.PrivacyOverview.IsAllowed = true;
      this.data?.Setting.SMS.IsAllowed = true;
      this.data?.Setting.SocialMediaCookies.IsAllowed = true;
      this.dataSC.add(this.data);

      this.toLoadedStatus();
    } catch (e) {
      this.toErrorStatus(e);
    }
  }

  Future<void> sendAllowConsentSetting(String id) async {
    try {
      this.toLoadingStatus();

      if (this.data?.Type == ConsentMessageTypes.tracking_type) {
        Pam.trackCustomEvent(eventName: "allow_consent", payload: {
          "_consent_message_id": id,
          "_allow_terms_and_conditions":
              this.data?.Setting.TermsAndConditions.IsAllowed ?? false,
          "_allow_privacy_overview":
              this.data?.Setting.PrivacyOverview.IsAllowed ?? false,
          "_allow_necessary_cookies":
              this.data?.Setting.NecessaryCookies.IsAllowed ?? false,
          "_allow_preferences_cookies":
              this.data?.Setting.PreferencesCookies.IsAllowed ?? false,
          "_allow_analytics_cookies":
              this.data?.Setting.AnalyticsCookies.IsAllowed ?? false,
          "_allow_marketing_cookies":
              this.data?.Setting.MarketingCookies.IsAllowed ?? false,
          "_allow_social_media_cookies":
              this.data?.Setting.SocialMediaCookies.IsAllowed ?? false,
        });
      } else if (this.data?.Type == ConsentMessageTypes.contacting_type) {
        Pam.trackCustomEvent(eventName: "allow_consent", payload: {
          "_consent_message_id": id,
          "_allow_terms_and_conditions":
              this.data?.Setting.TermsAndConditions.IsAllowed ?? false,
          "_allow_privacy_overview":
              this.data?.Setting.TermsAndConditions.IsAllowed ?? false,
          "_allow_email": this.data?.Setting.Email.IsAllowed ?? false,
          "_allow_sms": this.data?.Setting.SMS.IsAllowed ?? false,
          "_allow_line": this.data?.Setting.Line.IsAllowed ?? false,
          "_allow_facebook": this.data?.Setting.FacebookMessenger.IsAllowed ?? false,
          "_allow_mobile_notification":
              this.data?.Setting.MobileNotification.IsAllowed ?? false,
        });
      }

      await TimeHelper.sleep();

      this.toLoadedStatus();
    } catch (e) {
      this.toErrorStatus(e);
    }
  }
}
